Installing ``SCIMES``
=====================

Requirements
------------

* `Python <http://www.python.org>`_ 2.7 or later
* `Numpy <http://www.numpy.org>`_ 1.9.2 or later
* `Astropy <http://www.astropy.org>`_ 1.0.2 or later
* `Astrodendro <https://github.com/dendrograms/astrodendro>`_ 0.1.0 or later
* `scikit-learn <http://scikit-learn.org>`_ 0.15.2 or later

Optional packages
-----------------

* `Matplotlib <http://matplotlib.org>`_ 1.4.0 or later, optional (needed for visualizing the affinity matrices, clustered dendrogram)

Installation
------------

To install the latest stable release, you can type::

    pip install scimes
